mlstars.custom.timeseries\_preprocessing.intervals\_to\_mask
============================================================

.. currentmodule:: mlstars.custom.timeseries_preprocessing

.. autofunction:: intervals_to_mask